SnakeViz
========

.. image:: https://travis-ci.org/jiffyclub/snakeviz.svg?branch=master
    :target: https://travis-ci.org/jiffyclub/snakeviz
    :alt: Build Status

.. image:: https://img.shields.io/pypi/v/snakeviz.svg
    :target: https://pypi.python.org/pypi/snakeviz/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/pyversions/snakeviz.svg
    :target: https://pypi.python.org/pypi/snakeviz/
    :alt: Supported Python versions

.. image:: https://img.shields.io/pypi/format/snakeviz.svg
    :target: https://pypi.python.org/pypi/snakeviz/
    :alt: Wheel Status

About
-----

SnakeViz is a viewer for Python profiling data that runs as a web
application in your browser. It is inspired by the wxPython profile viewer
`RunSnakeRun <http://www.vrplumber.com/programming/runsnakerun/>`_.

Learn more about SnakeViz and submit bug reports at the official page:
http://jiffyclub.github.com/snakeviz/.
